Cesloi for mirai-api-http
=========================

一个简易，基于
```mirai-api-http v2`` <https://github.com/project-mirai/mirai-api-http>`__
的 Python SDK。

**本项目适用于 mirai-api-http 2.0 以上版本**\ 。

目前仍处于开发阶段，内部接口可能会有较大的变化。

注: mirai-api-http 需要启用ws adapter和http adapter

未来开发计划
------------

-  CommandAnalysis， 一个抽象的命令/命令参数处理器
-  TimeScheduler， 一个根据时间选择是否执行目标函数的容器
-  PluginManager， 不局限于在一个文件中运行方法

鸣谢&相关项目
-------------

    这些项目也很棒, 去他们的项目页看看, 点个 ``Star``
    以鼓励他们的开发工作, 毕竟没有他们也没有 ``Ariadne``. 特别感谢
    ```mamoe`` <https://github.com/mamoe>`__ 给我们带来这些精彩的项目: -
    ```mirai`` <https://github.com/mamoe/mirai>`__: 一个高性能,
    高可扩展性的 QQ 协议库 -
    ```mirai-console`` <https://github.com/mamoe/mirai-console>`__:
    一个基于 ``mirai`` 开发的插件式可扩展开发平台 -
    ```mirai-api-http`` <https://github.com/project-mirai/mirai-api-http>`__:
    为本项目提供与 ``mirai`` 交互方式的 ``mirai-console`` 插件
    ```GraiaProject`` <https://github.com/GraiaProject>`__ 下的项目: -
    ```Broadcast Control`` <https://github.com/GraiaProject/BroadcastControl>`__:
    扩展性强大, 模块间低耦合, 高灵活性的事件系统支持，是 ``Cesloi``
    的参考对象。 -
    ```Application`` <https://github.com/GraiaProject/Application/>`__:
    本项目的学习与参考对象，支持 ``mirai-api-http v1.x`` 版本 。 -
    ```Ariadne`` <https://github.com/GraiaProject/Ariadne/>`__:
    本项目关于网络部分的学习与参考对象。

许可证
~~~~~~

```GNU AGPLv3`` <https://choosealicense.com/licenses/agpl-3.0/>`__
是本项目的开源许可证.
